==========
PyOpenVidu
==========


.. image:: https://img.shields.io/pypi/v/pyopenvidu.svg
        :target: https://pypi.python.org/pypi/pyopenvidu

.. image:: https://img.shields.io/travis/marcsello/pyopenvidu.svg
        :target: https://travis-ci.com/marcsello/pyopenvidu

.. image:: https://readthedocs.org/projects/pyopenvidu/badge/?version=latest
        :target: https://pyopenvidu.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status




Python interface to the OpenVidu WebRTC videoconverence library.


* Free software: MIT license
* Documentation: https://pyopenvidu.readthedocs.io.


Features
--------

* Use OpenVidu API objects as native Python objects
* Supports Python 3.7 and above
* Depends on nothing more than `requests` and `requests-toolbelt`

Credits
-------

This implementation is inspired by the original Java implementation by the OpenVidu team.
https://openvidu.io/docs/reference-docs/openvidu-java-client/

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
